CacheStore

Trait CacheStore 

pub trait CacheStore {
    // Required methods
    fn init(&self) -> Result<()>;
    fn upsert_file(&self, path: &str, hash: &str, content: &[u8]) -> Result<i64>;
    fn get_file_hash(&self, path: &str) -> Result<Option<String>>;
    fn insert_symbol(&self, symbol: &Symbol) -> Result<()>;
    fn get_symbol_content(&self, symbol_id: &str) -> Result<Option<Vec<u8>>>;
    fn delete_file(&self, path: &str) -> Result<()>;
    fn get_file_symbols(&self, path: &str) -> Result<Vec<(String, String)>>;
    fn get_file_content(&self, path: &str) -> Result<Option<Vec<u8>>>;
    fn list_file_paths(&self) -> Result<Vec<String>>;
    fn list_files_with_symbols(&self) -> Result<FileSymbolList>;
    fn search_symbol_ids(&self, like_pattern: &str) -> Result<Vec<String>>;
}

Required Methods

fn init(&self) -> Result<()>

Initialize the database schema

fn upsert_file(&self, path: &str, hash: &str, content: &[u8]) -> Result<i64>

Insert or update a file and its content. Returns the file_id.

fn get_file_hash(&self, path: &str) -> Result<Option<String>>

Get a file’s hash to check if it has changed

fn insert_symbol(&self, symbol: &Symbol) -> Result<()>

Insert a symbol

fn get_symbol_content(&self, symbol_id: &str) -> Result<Option<Vec<u8>>>

Retrieve the raw bytes of a symbol using SQLite substr()

fn delete_file(&self, path: &str) -> Result<()>

Delete a file and cascade delete its symbols

fn get_file_symbols(&self, path: &str) -> Result<Vec<(String, String)>>

Get symbols for a file

fn get_file_content(&self, path: &str) -> Result<Option<Vec<u8>>>

Get the raw content bytes of a file by path

fn list_file_paths(&self) -> Result<Vec<String>>

List all file paths stored in the database

fn list_files_with_symbols(&self) -> Result<FileSymbolList>

List all files with their associated symbols (kind, name), ordered by byte_offset

fn search_symbol_ids(&self, like_pattern: &str) -> Result<Vec<String>>

Search symbol IDs whose name matches a SQL LIKE pattern

Implementors