Module plugin

Module plugin 

Structs

Packer
Bundles files and their enriched bones into an AI-friendly output format.

Enums

OutputFormat
Supported output formats for the packed context.

Traits

ContextPlugin
A plugin that can enrich extracted code bones with domain-specific metadata.