Structs
- Packer
- Bundles files and their enriched bones into an AI-friendly output format.
Enums
- Output
Format - Supported output formats for the packed context.
Traits
- Context
Plugin - A plugin that can enrich extracted code bones with domain-specific metadata.